/**
 * eobjects.org MetaModel
 * Copyright (C) 2010 eobjects.org
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.eobjects.metamodel.schema;

import java.util.List;

import org.eobjects.metamodel.util.BaseObject;

/**
 * Abstract {@link Column} implementation. Implements most common and trivial
 * methods.
 * 
 * @author Kasper Sørensen
 */
public abstract class AbstractColumn extends BaseObject implements Column {

    private static final long serialVersionUID = 1L;

    @Override
	public final String getQuotedName() {
		String quote = getQuote();
		if (quote == null) {
			return getName();
		}
		return quote + getName() + quote;
	}

	@Override
	public final String getQualifiedLabel() {
		StringBuilder sb = new StringBuilder();
		Table table = getTable();
		if (table != null) {
			sb.append(table.getQualifiedLabel());
			sb.append('.');
		}
		sb.append(getName());
		return sb.toString();
	}

	@Override
	public final int compareTo(Column that) {
		int diff = getQualifiedLabel().compareTo(that.getQualifiedLabel());
		if (diff == 0) {
			diff = toString().compareTo(that.toString());
		}
		return diff;
	}

	@Override
	public final String toString() {
		return "Column[name=" + getName() + ",columnNumber="
				+ getColumnNumber() + ",type=" + getType() + ",nullable="
				+ isNullable() + ",indexed=" + isIndexed() + ",nativeType="
				+ getNativeType() + ",columnSize=" + getColumnSize() + "]";
	}

	@Override
	protected final void decorateIdentity(List<Object> identifiers) {
		identifiers.add(getName());
		identifiers.add(getColumnNumber());
		identifiers.add(getType());
		identifiers.add(getNativeType());
		identifiers.add(isNullable());
		identifiers.add(getTable());
	}

	@Override
	protected final boolean classEquals(BaseObject obj) {
		return obj instanceof Column;
	}
}